type FetchOptions = RequestInit & {
    isCredentialsForCrossOrigin?: boolean;
    refetch?: number;
    retryAfter?: number;
};
type CustomError = {
    message: string;
    response: Response;
};
type UseFetchResult<T> = {
    data: T | null;
    error: CustomError | null;
    loading: boolean;
};

interface IUseIntersectionObserver extends IntersectionObserverInit {
    freezeOnceVisible?: boolean;
}
type IRef = React.RefObject<Element>;
type IIntersectionObserverReturn = {
    isIntersecting: IntersectionObserverEntry["isIntersecting"];
    elemRef?: IRef;
};

type LabelGetter = (label: string) => string | undefined;
type AllLabelsGetter = () => Record<string, string> | undefined;

declare const useFetch: <T>(url: string, options?: FetchOptions) => UseFetchResult<T>;

declare const useIntersectionObserver: (ref: IRef, { root, rootMargin, threshold, freezeOnceVisible, }: IUseIntersectionObserver) => IIntersectionObserverReturn | undefined;

declare const useDebounce: <T>(value: T, delay?: number) => T;

declare const useLocalStorage: <T>(key: string, initialState?: T | undefined) => [T, (value: T | null) => void];
declare const useSessionStorage: <T>(key: string, initialState?: T | undefined) => [T, (value: T | null) => void];

declare const useLocalizedContent: (url: string, languageStorageKey?: string, fetchOptions?: FetchOptions) => [boolean, LabelGetter, AllLabelsGetter];

declare const useThrottle: <T>(value: T, delay?: number) => T;

export { useDebounce, useFetch, useIntersectionObserver, useLocalStorage, useLocalizedContent, useSessionStorage, useThrottle };
